/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {stringify} from '../util/util';

const stringOrNull = string => {
	return string ? `'${string}'` : null;
};

const javascriptExample = ({contentType, data, method, url}) =>
	`const contentType = ${stringOrNull(contentType)};
const data = ${stringify(data)};
const method = '${method.toUpperCase()}';

const request = {
	method: method
};

if (method === 'POST' || method === 'PUT') {
	if (contentType === 'application/json') {
		request.body = JSON.stringify(data);

		const headers = new Headers();

		headers.append('Content-Type', contentType);

		request.headers = headers;
	}
	else if (contentType === 'multipart/form-data') {
		const formData  = new FormData();

		for(const name in data) {
			formData.append(name, data[name]);
		}

		request.body = formData;
	}
}

Liferay.Util.fetch(
	'${url}',
	request
).then(
	res => {
		let retVal;

		if (method == 'delete' && res.status == 204) {
			retVal = 'Deleted Successfully';
		}
		else {
			retVal = res.json();
		}

		return retVal;
	}
).then(res => {
	console.log('res', res);
});`;

export default javascriptExample;
